<?php
// $Id$

/**
 * @file
 * OM Maximenu Admin Utilities
 *
 * @author: Daniel Honrade http://drupal.org/user/351112
 *
 */
define('OM_MAXIMENU_PATH', drupal_get_path('module', 'om_maximenu')); 

drupal_add_css(OM_MAXIMENU_PATH . '/css/om_maximenu.css');
drupal_add_js(OM_MAXIMENU_PATH . '/js/om_maximenu.js', 'module'); 
     
/**
 * Load all OM Maximenu blocks
 * 
 * This will process all created OM Maximenu blocks
 *
 */
function om_maximenu_block_load($maximenu_delta = '') {

  $out = array();
  
  $maximenu_delta = explode('-', $maximenu_delta);
  // ex. $maximenu_delta = 'om-maximenu-1';
  $delta = $maximenu_delta[2];
  // om delta always starts with 1
  if ($delta != 0) {
  
    $menus = array();
    $maximenus = variable_get('om_maximenu', $menus);
    
    $skin = $maximenus[$delta]['skin'];
    $fade = $maximenus[$delta]['fade'];    

    $maximenu_name = om_string_name($maximenus[$delta]['title']); 
      
    // add css per OM Maximenu     
    drupal_add_css(OM_MAXIMENU_PATH . '/skin/' . $skin . '/' . $skin . '.css');
      
    // add js per OM Maximenu
    om_maximenu_hover_js($fade, 'om-maximenu-' . $maximenu_name);

    if (!empty($maximenus) && ($maximenus[$delta]['output'] == 'block')) {
      $out['title'] = $maximenus[$delta]['title'];
      $out['content'] = om_maximenu_links_render($maximenus[$delta], $maximenu_name);
    }
  }
  return $out;  
}


/**
 * Load all OM Maximenu blocks
 * 
 * This will process the main menu and floating blocks
 *
 */
function om_maximenu_load() {

  $menus = array();
  $maximenus = variable_get('om_maximenu', $menus);

  $out = array();
  foreach ($maximenus as $menu_key => $menu_content) {
    if ($menu_content['output'] != 'block') {
    
      $maximenu_name = om_string_name($menu_content['title']); 

      //$out[$menu_key]['title'] = $maximenus[$menu_key]['title'];
      $out[$menu_key]['output'] = $menu_content['output'];
      $out[$menu_key]['content'] = om_maximenu_links_render($maximenus[$menu_key], $maximenu_name);     
    }
  }
  return $out;  
}


/**
 * OM Maximenu links rendering engine
 *
 */
function om_maximenu_links_render($links = array(), $maximenu_name = NULL) {
  if (!isset($links['links'])) return NULL;
  global $user;
  //dsm($user);
  $user_id = $user->uid;  
  $user_roles = $user->roles;
  $count = 0;
  $total = count($links);
  $skin = ' om-maximenu-' . om_string_name($links['skin']);
  $output = ' om-maximenu-' . om_string_name($links['output']);
  
  if ($links['output'] == 'block') {
    $output_options = ' om-maximenu-block' . om_string_name($links['block_options']['direction']);   
  }
  elseif ($links['output'] == 'float') {
    $output_options = ' om-maximenu-' . om_string_name($links['float_options']['position']);   
  }
  elseif ($links['output'] == 'main_menu') {
    // no options yet
  }
  
  $maximenu_name = ' om-maximenu-' . $maximenu_name;
  
  $out = '<div class="om-maximenu' . $skin . $maximenu_name . $output . $output_options . '">';
  $out .= '<ul class="om-menu">';  

  usort($links['links'], 'om_sort_by_weight'); 
  $attributes = array();
  foreach ($links['links'] as $key => $content) {
    // user permission to view the link
    // roles
    // 1 - anonymous
    // 2 - authenticated
    //dsm($content['roles']);
    $roles = $content['roles'];
    $permission = array();
    $anyone = 0;
    foreach ($roles as $role => $value) {
       // check roles
       if (($value != 0) && isset($user_roles[$role])) $permission[$role] = $user_roles[$role];
       // for all roles are unchecked
       if ($value != 0) $anyone++;       
    }
    // the link will be visible if the user has permission or
    // the links is for everybody or
    // the user is a super user
    if (!empty($permission) || ($anyone == 0) || ($user_id == 1)) {    
      $count++;
      //dsm($content);
      $class_id = om_string_name($content['link_title']);
      
      $link_title_option = $content['link_title_option'];
      $link_title = $content['link_title'];      
      $link_icon = !empty($content['path_icon']) ? '<img src="' . base_path() . $content['path_icon'] . '" alt="' . $link_title . '" />': '';

      if ($link_title_option == 'title_icon') {
        $link_option = $link_icon . ' ' . $link_title;
      }
      elseif ($link_title_option == 'icon') {
        $link_option = $link_icon;
      }
      else {
        $link_option = $link_title;
      }
                        
      // li classes
      ($count == 1) ? $classes = ' first': $classes = '';
      if ($count == $total) $classes .= ' last';  
      $classes .= ' leaf-' . $class_id;     
      if ($_GET['q'] == $content['path']) $classes .= ' active'; 
      if (empty($content['path']) && drupal_is_front_page()) {
        $classes .= ' active'; 
        $content['class'] .= ' active'; 
      }  
      // user role class
      foreach ($permission as $pkey => $pval) {
        $pval = om_string_name($pval);
        $classes .= ' leaf-role-' . $pval; 
      }        
      // link attributes
      if (!empty($content['id'])) {
        $attributes['id'] = $content['id'];
        $span_id = 'id="' . $content['id'] . '"';        
      }
            
      $attributes['class'] = 'om-link ' . $content['class'] . ' link-' . $class_id;
      if (!empty($content['description'])) {
        $attributes['title'] = $content['description']; 
        $span_title = 'title="' . $content['description'] . '"'; 
      }    
      
      if (!empty($content['rel'])) $attributes['rel'] = $content['rel'];
      if (!empty($content['target']) && ($content['target'] != '_self')) $attributes['target'] = $content['target'];
            
      $out .= '<li id="om-leaf-' . $key . '" class="om-leaf' . $classes . '">';    
      if (!empty($content['path'])) {
        // Drupal doesn't accept # as valid path
        //$out .= l($content['link_title'], $content['path'], array('attributes' => $attributes));
        $path = ($content['path'] == '<front>') ? '': $content['path'];
        $out .= '<a ' . drupal_attributes($attributes) . ' href="' . base_path() . $path . '">' . $link_option . '</a>';
      }
      else {
        // useful when you just want a button for getting the content to show and not actually linking to anything
        $out .= '<span ' . $span_id . ' class="' . $attributes['class'] . '" ' . $span_title . '>' . $link_option . '</span>';
      }
      
      $out .= om_maximenu_content_render($content['content']);    
      $out .= '</li>';
    }
  }
  $out .= '</ul>';  
  
  // access on editing
  if (user_access('administer OM Maximenu')) $out .= '<div class="om-maximenu-edit"><a href="' . base_path() . 'admin/settings/om-maximenu?destination=' . $_GET['q'] . '">Edit Maximenu</a></div>';    
  
  $out .= '</div>';  
  
  return $out;
}


/**
 * OM Maximenu content rendering engine
 *
 */
function om_maximenu_content_render($content = '') {

  if (!empty($content)) {
    // enclose the content with divs for efficient image border theming
    $out = '<div class="om-maximenu-content om-maximenu-content-nofade">';
    $out .= '<div class="om-maximenu-top"><div class="om-maximenu-top-left"></div><div class="om-maximenu-top-right"></div></div>';
    $out .= '<div class="om-maximenu-middle"><div class="om-maximenu-middle-left"><div class="om-maximenu-middle-right">';      
    $count = 0;
    usort($content, 'om_sort_by_weight');  
    foreach ($content as $key => $prop) {
        $count++;
        ($count == 1) ? $classes = ' first': $classes = '';
        if ($count == $total) $classes .= ' last'; 
        $path = ($prop['title_path'] == '<front>') ? '': $prop['title_path'];
        $block_title = (!empty($prop['title_path'])) ? '<a href="' . base_path() . $path .'" title="' . $prop['title'] . '">' . $prop['title'] . '</a>': $prop['title'];      
        $block = module_invoke($prop['module'], 'block', 'view', $prop['delta']); 
        $out .= '<div class="block block-' . $prop['module'] . ' block-' . $prop['module'] . '-id-' . $prop['delta'] . $classes . '">';            
        $out .= ($prop['title'] != '<none>') ? '<h3 class="title">' . $block_title . '</h3>': ''; 
        $out .= $block['content']; 
        $out .= '</div>';            
    }
    $out .= '<div class="clearfix"></div></div></div></div>';      
    $out .= '<div class="om-maximenu-bottom"><div class="om-maximenu-bottom-left"></div><div class="om-maximenu-bottom-right"></div></div>';    
    $out .= '<div class="om-maximenu-arrow"></div>';    
    $out .= '</div>'; 
    return $out;
  } 
}

/**
 * Sorting by weight
 *
 */
function om_sort_by_weight($a, $b) {
  return $a['weight'] - $b['weight'];
}

/**
 * Sorting by weight
 *
 */
function om_string_name($var = NULL, $upper = 'lower') {
  // converts space and underscore to dash
  $pattern = '/[ _]+/';
  $var = ($upper == 'upper') ? ucwords(preg_replace($pattern, ' ', $var)): strtolower(preg_replace($pattern, '-', $var));
  return $var;
}

/**
 * OM Maximenu get styles from /skin directory
 * - reads directory names
 */
function om_maximenu_style_get() {
  $files = array();
  $dir = OM_MAXIMENU_PATH . '/skin/';
  $folders = scandir($dir);
  $excluded_files = array('.', '..', '.cvs', '.svn', '.git');

  foreach ($folders as $key => $val) {
    if (!in_array($val, $excluded_files)) (is_dir($dir . $val)) ? $files[$val] = om_string_name($val, 'upper'): '';     
  }
  return $files;
}


/**
 * Hover delay using hoverintent jquery plugin
 *
 */
function om_maximenu_hover_js($checked = 0, $menu = 'om-maximenu') {
  
  $add_js = "
    $(document).ready(function(){
      $('." . $menu . " li.om-leaf .om-maximenu-content').removeClass('om-maximenu-content-nofade');
      //$('." . $menu . " li.om-leaf').hover(omFadeIn,omFadeOut); //native jquery
      //$('." . $menu . " li.om-leaf').hoverIntent(omFadeIn,omFadeOut); //jquery hoverintent
      $('." . $menu . " li.om-leaf').hoverIntent({
        over: omFadeIn,
        timeout: 500,
        out: omFadeOut
      });
    });
    function omFadeIn(){ $('.om-maximenu-content', this).fadeIn();}
    function omFadeOut(){ $('.om-maximenu-content', this).fadeOut();} 
    ";
  if ($checked == 1) {
    drupal_add_js(OM_MAXIMENU_PATH . '/contrib/jquery.hoverIntent.minified.js', 'module'); 
    drupal_add_js($add_js, "inline");
  }
}


/**
 * Admin - hide/show options
 *
 */
function om_maximenu_admin_js() {
  
  $add_js = "
    $(document).ready(function(){

      $('form#om-maximenu-admin select.om-maximenu-output').change(function() {

        var parent_wrapper = $(this).parent().parent().parent().attr('id');  
        var output_value = $(this).val(); 
        
        if(output_value == 'block') {
          $('form#om-maximenu-admin fieldset#' + parent_wrapper + ' .om-maximenu-block-options').show();
          $('form#om-maximenu-admin fieldset#' + parent_wrapper + ' .om-maximenu-float-options').hide();          
        }
        if(output_value == 'float') {
          $('form#om-maximenu-admin fieldset#' + parent_wrapper + ' .om-maximenu-float-options').show();
          $('form#om-maximenu-admin fieldset#' + parent_wrapper + ' .om-maximenu-block-options').hide();
        }     
        if(output_value == 'main_menu') {
          $('form#om-maximenu-admin fieldset#' + parent_wrapper + ' .om-maximenu-float-options').hide();
          $('form#om-maximenu-admin fieldset#' + parent_wrapper + ' .om-maximenu-block-options').hide();
        } 
      });
    }); ";
  
  drupal_add_js($add_js, "inline");
}



